Portable

Trait Portable 

pub unsafe trait Portable: Flat { }
Type that can be safely transfered between different machines.

Safety

Implementing this trait must guarantee that Self has the same binary representation on any target platform this crate could be built for.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl Portable for i8

Source

impl Portable for u8

Source

impl<T> Portable for PhantomData<T>
where T: Portable,

Source

impl<T, L> Portable for GenericVec<[MaybeInvalid<T>], L>
where T: Portable, L: Portable + Length,

Source

impl<T, const N: usize> Portable for [T; N]
where T: Portable,

Implementors

Source

impl Portable for Bool

Source

impl<const BE: bool, const N: usize> Portable for Float<BE, N>

Source

impl<const BE: bool, const N: usize, const S: bool> Portable for Int<BE, N, S>