pub unsafe trait Portable: Flat { }Expand description
Type that can be safely transfered between different machines.
Safety
Implementing this trait must guarantee that Self has the same binary representation on any target platform this crate could be built for.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.